
## 📖 Agente para instrucao dentro do software
## **Notificaçoes em tempo real** 
  - Conceito: Ao o usuario navegar em uma seção do software um agente de inferencia em gpu notifica o usuario atraves de um custommodal como iniciar ou com outros tipos de detalhes a instrução do agente é flexivel e muda entre cada seção do software
